;; Generated package description from .el  -*- swiperno-byte-compile: t -*-
(define-package "swiper" "0.15.0.0.20250322.162553" "Isearch with an overview.  Oh, man!" '((emacs "24.5") (ivy "0.15.0")) :commit "c2ae13bc62019684c26e6fbd65d21bafc9300ceb" :authors '(("Oleh Krehel" . "ohwoeowho@gmail.com")) :maintainer '("Basil L. Contovounesios" . "basil@contovou.net") :keywords '("matching") :url "https://github.com/abo-abo/swiper")
